@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Conf;
-$ExtUtils::Builder::Conf::VERSION = '0.033';
+$ExtUtils::Builder::Conf::VERSION = '0.034';
 use strict;
 use warnings;
 
@@ -74,7 +74,7 @@ sub add_methods {
 		print $source_file $args{source};
 
 		my $inner = $self->new_planner;
-		$inner->load_extension('ExtUtils::Builder::AutoDetect::C', 0.015);
+		$inner->load_extension('ExtUtils::Builder::BuildTools::FromPerl', 0.034);
 
 		my @include_dirs         = (@{ $args{include_dirs} // [] },         @{ $self->{include_dirs} // [] });
 		my @extra_compiler_flags = (@{ $args{extra_compiler_flags} // [] }, @{ $self->{extra_compiler_flags} // [] });
@@ -243,7 +243,7 @@ ExtUtils::Builder::Conf - Configure-time utilities for using C headers, librarie
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
